@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12486 2020-08-27 11:15:48Z Casey $
+# $Id: models.py 12487 2020-08-27 11:21:50Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2020-08-27 19:15:48 +0800 (Thu, 27 Aug 2020) $
-# $Revision: 12486 $
+# $Date: 2020-08-27 19:21:50 +0800 (Thu, 27 Aug 2020) $
+# $Revision: 12487 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -37,7 +37,7 @@ class AdminPlaceholder(models.Model):
 
     class Meta:
         verbose_name = _('AdminPlaceholder')
-        verbose_name_plural = _('AdminPlaceholderr')
+        verbose_name_plural = _('AdminPlaceholder')
         
         
 class BlockDisplayControl(models.Model):
